@@ -21,9 +21,6 @@ NOSE_ARGS = [
     # '--exe',  # If your tests need this to be found/run, check they py files are not chmodded +x
 ]
 
-CACHES['default'] = {'BACKEND': 'django.core.cache.backends.db.DatabaseCache'}
-
-
 PASSWORD_HASHERS = [
     'django.contrib.auth.hashers.MD5PasswordHasher',
 ]
@@ -38,3 +35,20 @@ PASSWORD_HASHERS = [
 ESI_SSO_CLIENT_ID = '123'
 ESI_SSO_CLIENT_SECRET = '123'
 ESI_SSO_CALLBACK_URL = '123'
+
+CACHES = {
+    "default": {
+        # AA 2.x
+        # "BACKEND": "redis_cache.RedisCache",
+        # "LOCATION": "localhost:6379",
+        # "OPTIONS": {
+        #    "DB": 1,
+        # }
+        # AA 3.x
+        "BACKEND": "django_redis.cache.RedisCache",
+        "LOCATION": "redis://localhost:6379/1",
+        "OPTIONS": {
+            "COMPRESSOR": "django_redis.compressors.lzma.LzmaCompressor",
+        }
+    }
+}
